==> grafana-2024.2.160+6b985e51b.tgz: grafana/CHANGELOG.md <==
# Release notes

## 2024.2.0-40

- 0.1.0 Initial Chart
- 0.1.1 Change helm-toolkit dependency version to ">= 0.1.0"
- 0.1.2 Update Grafana version
- 0.1.3 Provision any dashboard as homepage
- 0.1.4 Enable TLS for Grafana
- 0.1.5 Enable TLS between Grafana and Prometheus
- 0.1.6 Enable TLS for Grafana ingress path
- 0.1.7 Update Grafana version and Selenium script
- 0.1.8 Use full image ref for docker official images
- 0.1.9 Add Alertmanager dashboard to Grafana
- 0.1.10 Helm 3 - Fix Job labels
- 0.1.11 Update htk requirements
- 0.1.12 Add iDRAC dashboard to Grafana
- 0.1.13 Update prometheus metric name
- 0.1.14 Add run migrator job
- 0.1.15 Added OCI registry authentication
- 0.1.16 Grafana 8.5.10 with unified alerting
- 0.1.17 Fix uid for the user grafana
- 0.1.18 Migrator job is now mariadb-fail-proof
- 0.1.19 Update grafana to 9.2.10
- 0.1.20 Upgrade osh-selenium image to latest-ubuntu_focal
- 0.1.21 Fix run migrator job deployment condition
- 0.1.22 Make selenium v4 syntax optional
- 0.1.23 Modified selenium test for compatibility
- 0.1.24 Add image rendering sidecar
- 0.1.25 Add value for rendering sidecar feature
- 0.1.26 Use quay.io/airshipit/kubernetes-entrypoint:latest-ubuntu_focal by default
- 0.1.27 Update default images tags. Add 2024.1-ubuntu_jammy overrides.
- 0.1.28 Upgrade osh-selenium image to ubuntu_jammy
- 0.1.29 Add 2024.2 overrides
- 0.1.30 Update chart helm test environment variables
- 0.1.31 Update Chart.yaml apiVersion to v2
- 2024.2.0 Update version to align with the Openstack release cycle

## 2024.2.0

Before 2024.2.0 all the OpenStack-Helm charts were versioned independently.
Here we provide all the release notes for the chart for all versions before 2024.2.0.

==> grafana-2025.1.0+35052e51b.tgz: grafana/CHANGELOG.md <==
# Release notes

## 2025.1.0-83

### New Features

- Update apparmor values to use security_context instead of annotations.
- Add support for runtimeClassName and priorityClassName

## 2025.1.0

- 0.1.0 Initial Chart
- 0.1.1 Change helm-toolkit dependency version to ">= 0.1.0"
- 0.1.2 Update Grafana version
- 0.1.3 Provision any dashboard as homepage
- 0.1.4 Enable TLS for Grafana
- 0.1.5 Enable TLS between Grafana and Prometheus
- 0.1.6 Enable TLS for Grafana ingress path
- 0.1.7 Update Grafana version and Selenium script
- 0.1.8 Use full image ref for docker official images
- 0.1.9 Add Alertmanager dashboard to Grafana
- 0.1.10 Helm 3 - Fix Job labels
- 0.1.11 Update htk requirements
- 0.1.12 Add iDRAC dashboard to Grafana
- 0.1.13 Update prometheus metric name
- 0.1.14 Add run migrator job
- 0.1.15 Added OCI registry authentication
- 0.1.16 Grafana 8.5.10 with unified alerting
- 0.1.17 Fix uid for the user grafana
- 0.1.18 Migrator job is now mariadb-fail-proof
- 0.1.19 Update grafana to 9.2.10
- 0.1.20 Upgrade osh-selenium image to latest-ubuntu_focal
- 0.1.21 Fix run migrator job deployment condition
- 0.1.22 Make selenium v4 syntax optional
- 0.1.23 Modified selenium test for compatibility
- 0.1.24 Add image rendering sidecar
- 0.1.25 Add value for rendering sidecar feature
- 0.1.26 Use quay.io/airshipit/kubernetes-entrypoint:latest-ubuntu_focal by default
- 0.1.27 Update default images tags. Add 2024.1-ubuntu_jammy overrides.
- 0.1.28 Upgrade osh-selenium image to ubuntu_jammy
- 0.1.29 Add 2024.2 overrides
- 0.1.30 Update chart helm test environment variables
- 0.1.31 Update Chart.yaml apiVersion to v2
- 2024.2.0 Update version to align with the Openstack release cycle

## 2024.2.0

Before 2024.2.0 all the OpenStack-Helm charts were versioned independently.
Here we provide all the release notes for the chart for all versions before 2024.2.0.
